==> vtigercrm-5.3.0p0.tgz: modules/com_vtiger_workflow/language/es_mx.lang.php <==
<?php
/**
  JPL TSolucio, S.L. 2009 MPL
  Joe Bordes
   * Es_mx Author: Francisco Hernandez Odin Consultores www.odin.mx 
 **/

$mod_strings = array(
'VTEmailTask' => 'Enviar Correo',
'VTEntityMethodTask' => 'Ejecutar Función',
'VTCreateTodoTask' => 'Crear Tarea',
'VTCreateEventTask' => 'Crear Evento',
'VTSMSTask' => 'Enviar SMS',
'LBL_EDIT_TASK'=>'Editar Tarea',
'LBL_EDIT_TASK_TITLE'=>'Editar una tarea existente o crear una nueva',
'LBL_EDIT_WORKFLOW'=>'Editar Flujo Trabajo',
'LBL_EDIT_WORKFLOW_TITLE'=>'Editar un flujo de trabajo existente o crear uno nuevo',
'LBL_FROM_TEMPLATE'=>'De Plantilla',
'LBL_NEW_WORKFLOW'=>'Nuevo Flujo de Trabajo',
'LBL_NEW_TEMPLATE'=>'Guardar como Plantilla',
'LBL_CREATE_WORKFLOW_FOR'=>'Crear un flujo de trabajo para',
'LBL_FOR_MODULE'=>'Para Módulo',
'LBL_CHOOSE_A_TEMPLATE'=>'Seleccione plantilla',
'LBL_VALIDATION_MISSING_MANDATORY_FIELDS'=>'Hay campos obligatorios vacíos.',
'LBL_VALIDATION_INVALID_DATE_RANGE'=>'Fecha/Hora de inicio es superior a Fecha/Hora fin',
'LBL_ERROR_NO_WORKFLOW'=>'El flujo de trabajo al que intentas acceder no existe',
'LBL_ERROR_NO_TASK'=>'La tarea a la que intentas acceder no existe',
'LBL_ERROR_NOT_ADMIN'=>'Solo el usuario administrador tiene acceso a este módulo',
'LBL_CREATE_WORKFLOW'=>'Crear flujo trabajo',
'LBL_WORKFLOW_LIST'=>'Flujos de Trabajo',
'LBL_AVAILABLE_WORKLIST_LIST'=>'Flujos de Trabajo Disponibles',
'LBL_LOADING'=>'Cargando...',
'LBL_VALIDATION_ERROR'=>'Error de Validación',
'LBL_SELECT_OPTION_DOTDOTDOT'=>'Selecciona Opción...',
'LBL_WORKFLOW_NOTE_CRON_CONFIG'=>'NOTA: Debes configurar la tarea programada (Cron Job) de Flujo de Trabajo.',
'LBL_NO_TEMPLATES'=>'Sin Plantillas',
'LBL_SELECT'=>'Selecciona',
'LBL_MESSAGE'=>'Mensaje',
'LBL_SET_FIELD_VALUES'=>'Establecer valor de campo',
'LBL_ADD_FIELD'=>'Agregar campo',

'LBL_USE_FIELD_VALUE_DASHDASH'=>'-- Utilizar Valor --',
'LBL_USE_FUNCTION_DASHDASH'=>'-- Utilizar Función --',

'LBL_RAW_TEXT'=>'Texto',
'LBL_FIELD'=>'Campo',
'LBL_EXPRESSION'=>'Expresión',
'LBL_SET_EXPRESSION'=>'Definir Expresión',

'LBL_MANUAL'=>'Manual/Sistema',

'LBL_NEW_CONDITION_GROUP_BUTTON_LABEL'=>'Añadir Condición de Grupo',

'VTUpdateFieldsTask' => 'Actualizar Campos',

'LBL_VALIDATION_DUPLICATE_FIELDNAMES' => 'El mismo campo ha sido seleccionado más de una vez.',
'LBL_VALIDATION_INVALID_FIELD_VALUES' => 'Valores de Campos Inválidos',
'LBL_CREATE_ENTITY_NOTE_ORDER_MATTERS' => 'Nota: Las expresiones se evalúan en el orden de los campos.
											Considere asignar un valor al campo antes de utilizarlo.',
'LBL_SET_VALUE' => 'Establecer Valor',

'LBL_EMAIL_RECIPIENT' => 'Destinatario',
'LBL_EMAIL_CC' => 'CC',
'LBL_EMAIL_BCC' => 'BCC',
'LBL_EMAIL_SUBJECT' => 'Asunto',

'LBL_WORKFLOW_NOTE_EVENT_TASK_TIMEZONE' => 'Nota: Todas las fechas, horas e información recurrente configurada para el evento,
											estarán definidas conforme a la zona horaria por defecto, configurada en config.inc.php',

);
?>

==> vtigercrm-5.4.0.tgz: modules/com_vtiger_workflow/language/es_mx.lang.php <==
<?php
/**
  JPL TSolucio, S.L. 2009 MPL
  
   * Es_mx Author: Francisco Hernandez Odin Consultores www.odin.mx 
 **/

$mod_strings = array(
'VTEmailTask' => 'Enviar Correo',
'VTEntityMethodTask' => 'Ejecutar Función',
'VTCreateTodoTask' => 'Crear Tarea',
'VTCreateEventTask' => 'Crear Evento',
'VTSMSTask' => 'Enviar SMS',
'LBL_EDIT_TASK'=>'Editar Tarea',
'LBL_EDIT_TASK_TITLE'=>'Editar una tarea existente o crear una nueva',
'LBL_EDIT_WORKFLOW'=>'Editar Flujo Trabajo',
'LBL_EDIT_WORKFLOW_TITLE'=>'Editar un flujo de trabajo existente o crear uno nuevo',
'LBL_FROM_TEMPLATE'=>'De Plantilla',
'LBL_NEW_WORKFLOW'=>'Nuevo Flujo de Trabajo',
'LBL_NEW_TEMPLATE'=>'Guardar como Plantilla',
'LBL_CREATE_WORKFLOW_FOR'=>'Crear un flujo de trabajo para',
'LBL_FOR_MODULE'=>'Para Módulo',
'LBL_CHOOSE_A_TEMPLATE'=>'Seleccione plantilla',
'LBL_VALIDATION_MISSING_MANDATORY_FIELDS'=>'Hay campos obligatorios vacíos.',
'LBL_VALIDATION_INVALID_DATE_RANGE'=>'Fecha/Hora de inicio es superior a Fecha/Hora fin',
'LBL_ERROR_NO_WORKFLOW'=>'El flujo de trabajo al que intentas acceder no existe',
'LBL_ERROR_NO_TASK'=>'La tarea a la que intentas acceder no existe',
'LBL_ERROR_NOT_ADMIN'=>'Solo el usuario administrador tiene acceso a este módulo',
'LBL_CREATE_WORKFLOW'=>'Crear flujo trabajo',
'LBL_WORKFLOW_LIST'=>'Flujos de Trabajo',
'LBL_AVAILABLE_WORKLIST_LIST'=>'Flujos de Trabajo Disponibles',
'LBL_LOADING'=>'Cargando...',
'LBL_VALIDATION_ERROR'=>'Error de Validación',
'LBL_SELECT_OPTION_DOTDOTDOT'=>'Selecciona Opción...',
'LBL_WORKFLOW_NOTE_CRON_CONFIG'=>'NOTA: Debes configurar la tarea programada (Cron Job) de Flujo de Trabajo.',
'LBL_NO_TEMPLATES'=>'Sin Plantillas',
'LBL_SELECT'=>'Selecciona',
'LBL_MESSAGE'=>'Mensaje',
'LBL_SELECT'=>'Selecciona',
'LBL_MESSAGE'=>'Mensaje',
'LBL_SEND_ALL_ATTACHMENT'=>'Enviar todos los adjuntos',
'VTPDFMakerTask'=>'Guardar documento de PDFMaker',  // ITS4YOU-CR PDF Maker
'LBL_SEND_ALL_ATTACHMENT'=>'Enviar todos los adjuntos', 
'LBL_SET_FIELD_VALUES'=>'Establecer valor de campo',
'LBL_ADD_FIELD'=>'Agregar campo',

'LBL_USE_FIELD_VALUE_DASHDASH'=>'-- Utilizar Valor --',
'LBL_USE_FUNCTION_DASHDASH'=>'-- Utilizar Función --',

'LBL_RAW_TEXT'=>'Texto',
'LBL_FIELD'=>'Campo',
'LBL_EXPRESSION'=>'Expresión',
'LBL_SET_EXPRESSION'=>'Definir Expresión',

'LBL_MANUAL'=>'Sistema',

'LBL_NEW_CONDITION_GROUP_BUTTON_LABEL'=>'Añadir Condición de Grupo',

'VTUpdateFieldsTask' => 'Actualizar Campos',

'LBL_VALIDATION_DUPLICATE_FIELDNAMES' => 'El mismo campo ha sido seleccionado más de una vez.',
'LBL_VALIDATION_INVALID_FIELD_VALUES' => 'Valores de Campos Inválidos',
'LBL_CREATE_ENTITY_NOTE_ORDER_MATTERS' => 'Nota: Las expresiones se evalúan en el orden de los campos.
											Asegúrate de asignar un valor al campo antes de utilizarlo.',
'LBL_SET_VALUE' => 'Establecer Valor',

'LBL_EMAIL_RECIPIENT' => 'Destinatario',
'LBL_EMAIL_CC' => 'CC',
'LBL_EMAIL_BCC' => 'BCC',
'LBL_EMAIL_SUBJECT' => 'Asunto',

'LBL_WORKFLOW_NOTE_EVENT_TASK_TIMEZONE' => 'Nota: Todas las fechas, horas e información recurrente configurada para el evento,
											estarán definidas conforme a la zona horaria por defecto, configurada en config.inc.php',
'Select Meta Variables' => 'Selecciona Meta Variables',
'Current Date' => 'Fecha Actual',
'Current Time' => 'Hora Actual',
'System Timezone' => 'Zona Horaria del Sistema',
'CRM Detail View URL' => 'URL Vista Detalle del CRM',
'Portal Detail View URL' => 'URL Vista Detalle del Portal',
'Site Url' => 'Url CRM',
'Portal Url' => 'Url Portal',

'Workflow'=>'Flujo de Trabajo',

'VTCreateEntityTask' => 'Crear Entidad',
'LBL_ENTITY_TYPE' => 'Tipo Entidad',
'LBL_SELECT_ENTITY_TYPE' => '-- Selecciona Tipo Entidad --',
'LBL_NO_ENTITIES_FOUND' => 'No se han encontrado entidades para crear',

);
?>
